==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/AcceptEventSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.AcceptEvent;
import io.ciera.tool.sql.ooaofooa.activity.AcceptEventActionSet;
import io.ciera.tool.sql.ooaofooa.activity.AcceptEventSet;
import io.ciera.tool.sql.ooaofooa.activity.AcceptTimeEventActionSet;
import io.ciera.tool.sql.ooaofooa.activity.ActionNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.AcceptEventActionSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.AcceptTimeEventActionSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.ActionNodeSetImpl;

import java.util.Arrays;
import java.util.List;


public class AcceptEventSetImpl extends InstanceSet<AcceptEventSet,AcceptEvent> implements AcceptEventSet {

    // attributes
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( AcceptEvent acceptevent : this ) acceptevent.setId( ref_Id );
    }


    // selections
    @Override
    public ActionNodeSet R1107_is_a_ActionNode() throws XtumlException {
        ActionNodeSet actionnodeset = new ActionNodeSetImpl();
        for ( AcceptEvent acceptevent : this ) actionnodeset.add( acceptevent.R1107_is_a_ActionNode() );
        return actionnodeset;
    }
    @Override
    public AcceptEventActionSet R1112_is_a_AcceptEventAction() throws XtumlException {
        AcceptEventActionSet accepteventactionset = new AcceptEventActionSetImpl();
        for ( AcceptEvent acceptevent : this ) accepteventactionset.add( acceptevent.R1112_is_a_AcceptEventAction() );
        return accepteventactionset;
    }
    @Override
    public AcceptTimeEventActionSet R1112_is_a_AcceptTimeEventAction() throws XtumlException {
        AcceptTimeEventActionSet accepttimeeventactionset = new AcceptTimeEventActionSetImpl();
        for ( AcceptEvent acceptevent : this ) accepttimeeventactionset.add( acceptevent.R1112_is_a_AcceptTimeEventAction() );
        return accepttimeeventactionset;
    }


    @Override
    public AcceptEvent nullElement() {
        return AcceptEventImpl.EMPTY_ACCEPTEVENT;
    }

    @Override
    public AcceptEventSet emptySet() {
      return new AcceptEventSetImpl();
    }

    @Override
    public AcceptEventSet value() {
        return this;
    }

    @Override
    public List<AcceptEvent> elements() {
        return Arrays.asList(toArray(new AcceptEvent[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/AcceptEventSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.AcceptEvent;
import io.ciera.tool.sql.ooaofooa.activity.AcceptEventActionSet;
import io.ciera.tool.sql.ooaofooa.activity.AcceptEventSet;
import io.ciera.tool.sql.ooaofooa.activity.AcceptTimeEventActionSet;
import io.ciera.tool.sql.ooaofooa.activity.ActionNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.AcceptEventActionSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.AcceptTimeEventActionSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.ActionNodeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class AcceptEventSetImpl extends InstanceSet<AcceptEventSet,AcceptEvent> implements AcceptEventSet {

    public AcceptEventSetImpl() {
    }

    public AcceptEventSetImpl(Comparator<? super AcceptEvent> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( AcceptEvent acceptevent : this ) acceptevent.setId( ref_Id );
    }


    // selections
    @Override
    public ActionNodeSet R1107_is_a_ActionNode() throws XtumlException {
        ActionNodeSet actionnodeset = new ActionNodeSetImpl();
        for ( AcceptEvent acceptevent : this ) actionnodeset.add( acceptevent.R1107_is_a_ActionNode() );
        return actionnodeset;
    }
    @Override
    public AcceptEventActionSet R1112_is_a_AcceptEventAction() throws XtumlException {
        AcceptEventActionSet accepteventactionset = new AcceptEventActionSetImpl();
        for ( AcceptEvent acceptevent : this ) accepteventactionset.add( acceptevent.R1112_is_a_AcceptEventAction() );
        return accepteventactionset;
    }
    @Override
    public AcceptTimeEventActionSet R1112_is_a_AcceptTimeEventAction() throws XtumlException {
        AcceptTimeEventActionSet accepttimeeventactionset = new AcceptTimeEventActionSetImpl();
        for ( AcceptEvent acceptevent : this ) accepttimeeventactionset.add( acceptevent.R1112_is_a_AcceptTimeEventAction() );
        return accepttimeeventactionset;
    }


    @Override
    public AcceptEvent nullElement() {
        return AcceptEventImpl.EMPTY_ACCEPTEVENT;
    }

    @Override
    public AcceptEventSet emptySet() {
      return new AcceptEventSetImpl();
    }

    @Override
    public AcceptEventSet emptySet(Comparator<? super AcceptEvent> comp) {
      return new AcceptEventSetImpl(comp);
    }

    @Override
    public AcceptEventSet value() {
        return this;
    }

    @Override
    public List<AcceptEvent> elements() {
        return Arrays.asList(toArray(new AcceptEvent[0]));
    }

}
